cratestack_annotations library

Annotations consumed by CrateStack's Dart code generators.

Runtime-only and dependency-free — see pubspec.yaml for why this is a separate package from cratestack_builder, which does the generating.

Classes

CratestackBuilder
Marks a generated data class as needing a fluent builder.